==> haskell-binary-conduit-1.3.1-529-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-9wJKb2sTSsaI0m6nGdgVLB
key:                  binary-conduit-1.3.1-9wJKb2sTSsaI0m6nGdgVLB
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  733fe21c6a89aad2b0e0015cd2d653de
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-9wJKb2sTSsaI0m6nGdgVLB
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5ZSsm3oucHaEmMgze2N1VX exceptions-0.10.5
    vector-0.13.2.0-GTax7SJDHXyLP8P6Lzhygl

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-530-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-IeajA2kzqAFENpB1HsAACd
key:                  binary-conduit-1.3.1-IeajA2kzqAFENpB1HsAACd
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  0e69d70f3b03064466f0c4550c310ff8
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-IeajA2kzqAFENpB1HsAACd
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-B7V1OlOMAuaARuDzpB8NsU exceptions-0.10.5
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
